;
; HORIZONTAL PLAYER MOTION TEST
;
; FIDDLING WITH THE HSCROL REGISTER, USING VBI TO SET ZERO PAGE COUNTERS
; AND FLAGS, AND USING THE DLI TO INTERPRET AND SET THE SCROLL REGISTERS
; ACCORDINGLY.
;

		.INCLUDE atariequ.asm
		.INCLUDE ../font1.asm

; 
; CONSTANTS
;
DIRLEFT			= $00			; GO LEFT
DIRRIGHT		= $01			; GO RIGHT
MAXINVLEFT		= $75			; MAXIMUM LMS COUNTER FOR LEFT EXTREME AT START
MAXINVRIGHT		= $65			; MAXIMUM LMS COUNTER FOR RIGHT EXTREME AT START

HSCRCTR			= $80			; HORIZONTAL FINE SCROLL COUNTER
HPLRCTR			= $81			; HORIZONTAL PLAYER FINE SCROLL COUNTER
PLRDIR			= $82			; PLAYER LEFT (0) OR RIGHT(1)
HPLRLMS			= $83			; PLAYER LMS INSTRUCTION
HMONSCR			= $84			; MOON FINE SCROLL HSCROL
HMONLMS			= $85			; MOON LMS SCROLL
HINVDIR			= $86			; INVADERS DIRECTION
HINVSCR			= $87			; INVADERS SCROLL REGISTER
HINVLMS			= $88			; INVADERS LMS COARSE SCROLL
HINVMXL			= $89			; INVADERS LMS MAX LEFT
HINVMXR			= $8A			; INVADERS LMS MAX RIGHT


		*=$0700
	
TOP		JMP START

;
; TABLES
;
GCPLT		.BYTE $02,$04,$08,$0A,$00			; DEFAULT GAME COLORS
	
START		CLD

;
; SET GAME COLORS
;

SETGC		LDX #$04
SETGCL		LDA GCPLT,X
		STA COLOR0,X
		DEX
		STA COLOR0,X
		BNE SETGCL

;
; INITIALIZE THE DISPLAY REGISTERS.
;
INITVALS	LDA #$00			; INITIALISE THE SCROLL REGISTERS
		STA HMONSCR			;
		STA HINVSCR			;
		LDA #$75			; SET THE INITIAL MAX LEFT EXTREME
		STA HINVMXL			;
		LDA #$65			; SET THE INITIAL MAX RIGHT EXTREME
		STA HINVMXR			; 
		LDA #$01			; GO RIGHT.
		STA HINVDIR			; INITIALISE THE DIRECTION REGISTERS
		LDA #$89			; INITIALISE THE INVADERS LMS COUNTER
		STA HINVLMS			; 
		LDA #$DC			; INITIALISE THE MOON LMS COUNTER.
		STA HMONLMS			;


;
; SET UP PLAYFIELD/PLAYER-MISSILE DMA
;

SETPF		LDA #$3D		; NARROW, PLAYER, MISSILE, 1 LINE P/M, INSTRUCTION FETCH DMA
		STA SDMCTL		;
SETPM		LDA #$03		; PLAYER/MISSILE DMA TO GTIA
		STA GRACTL		;

;
; SET DISPLAY LIST
;

SETDL		LDA #<DLIST
		STA SDLSTL
		LDA #>DLIST
		STA SDLSTL+1

;
; SET DLI VECTOR
;

SETDLI		LDA #<DLI1
		STA VDSLST
		LDA #>DLI1
		STA VDSLST+1
		LDA #$C0
		STA NMIEN

;
; SET UP CHARACTER SET
;

SETCHR		LDA #>FONT1
		STA CHBAS

;
; SET UP THE VBI ROUTINE
; 
SETVBI		LDY #<VBIRT				; LOW BYTE
		LDX #>VBIRT				; HI BYTE
		LDA #$06				; IMMEDIATE VBI
		JSR SETVBV

;
; THE MAIN GAME LOOP
;
BEGLOOP		LDA HINVDIR				; CHECK INVADERS DIRECTION
		CMP #$01				; GOING RIGHT?
		BEQ CHKR				; YES, CHECK IF WE ARE GOING ALL THE WAY RIGHT?
CHKL		LDA HINVLMS				; GET THE CURRENT LMS COUNTER
		CMP HINVMXL				; ARE WE ALL THE WAY LEFT?
		BNE ENDLOOP				; NO, GO TO THE END OF THE LOOP.
GORIGHT		LDA #$01				; SET DIRECTION TO RIGHT
		STA HINVDIR				; AND STORE IT.
		JMP ENDLOOP				; AND GO TO THE END OF THE LOOP.
CHKR		LDA HINVLMS				; 
		CMP HINVMXR				; ARE WE ALL THE WAY RIGHT?
		BNE ENDLOOP				; NO...
GOLEFT		LDA #$00				; SET DIRECTION TO LEFT
		STA HINVDIR				; 
		JMP ENDLOOP				;
ENDLOOP		JMP BEGLOOP				; AND GO BACK TO BEGINNING.


; ------ END MAIN LINE CODE ---------------

;
; VBI ROUTINES
;
VBIRT		LDA #$00				; KILL THE ATTRACT!
		STA ATRACT				;
		LDA RTCLOK+2				;
		AND #$00				;
		BNE VBUPDMO				; NOT READY YET, SKIP AHEAD.
VBINVDIR	LDA HINVDIR				; FIND OUT IF WE NEED TO BE GOING LEFT OR RIGHT?
		CMP #$00				;
		BNE VBINVRIG				; YES, GO RIGHT.
VBINVLEF	LDA HINVSCR				; CHECK SCROLL REGISTER
		CMP #$00				; ALL THE WAY LEFT?
		BEQ VBINVLLMS				; YES, DO A COARSE SCROLL LEFT.
		DEC HINVSCR				; SCROLL LEFT.
		JMP VBUPDMO				; CONTINUE THE VBI ROUTINE.
VBINVLLMS	INC HINVLMS				; DECREMENT THE LMS SCROLL
		INC HINVLMS				;
		INC HINVLMS				;
		INC HINVLMS				;
		LDA HINVLMS				; GRAB THE LMS OFFSET
		STA DLINV1+1				; UPDATE THE INVADERS LMS
		STA DLINV2+1				;
		STA DLINV3+1				;
		STA DLINV4+1				;
		STA DLINV5+1				;
		LDA #$0F				; RESET THE SCROLL REGISTER.
		STA HINVSCR				;
		JMP VBUPDMO				; CONTINUE ON...
VBINVRIG	LDA HINVSCR				; CHECK SCROLL REGISTER
		CMP #$0F				; ALL THE WAY RIGHT?
		BEQ VBINVRLMS				; YES, DO A COARSE SCROLL RIGHT.
		INC HINVSCR				; SCROLL RIGHT
		JMP VBUPDMO				; CONTINUE THE VBI ROUTINE
VBINVRLMS	DEC HINVLMS				; INCREMENT THE LMS SCROLL
		DEC HINVLMS				;
		DEC HINVLMS				;
		DEC HINVLMS				;
		LDA HINVLMS				; GRAB THE LMS OFFSET
		STA DLINV1+1				; UPDATE THE INVADERS LMS
		STA DLINV2+1				;
		STA DLINV3+1				;
		STA DLINV4+1				;
		STA DLINV5+1				;
		LDA #$00				; RESET THE SCROLL REGISTER
		STA HINVSCR				;
		JMP VBUPDMO				; AND CONTINUE ON...
VBUPDMO		LDA RTCLOK+2				; TRIGGER EVERY 16 VBLANKS
		AND #$01				;
		BNE VBDON				;
VBIHSCRL	LDA HMONSCR				; GRAB CURRENT SCROLL REGISTER
		CMP #$0F
		BEQ VBILMS				; YES, INCREMENT THE LMS
		INC HMONSCR				; INCREMENT THE MOON SCROLLER
		JMP VBDON				; AND COMPLETE THE ROUTINE.
VBILMS		DEC HMONLMS				; DECREMENT THE LMS SCROLL
		DEC HMONLMS				;
		DEC HMONLMS				;
		DEC HMONLMS				;
		LDA HMONLMS				;
		AND #$7F				; MASK OFF THE 8TH BIT.
		STA DLMOON1+1				; UPDATE THE COARSE SCROLL
		STA DLMOON2+1				;
		STA DLMOON3+1				;
		STA DLMOON4+1				;
		LDA #$00				;
		STA HMONSCR				;
		JMP VBDON				;
VBDON		JMP SYSVBV				; AND COMPLETE THE VBI ROUTINE.
		

;
; DLI ROUTINES
;

DLI1		PHA
		STA WSYNC
		LDA #$26
		STA WSYNC
		STA COLPF0
		LDA #$28
		STA WSYNC
		STA COLPF1
		LDA #$2A
		STA WSYNC
		STA COLPF2
		LDA #$2C
		STA WSYNC
		STA COLPF3
		LDA #<DLI2
		STA VDSLST
		LDA #>DLI2
		STA VDSLST+1
		PLA
		RTI
DLI2		PHA
		LDA HINVSCR			
		STA HSCROL			      
		LDA #$16
		STA WSYNC
		STA COLPF0
		LDA #$18
		STA WSYNC
		STA COLPF1
		LDA #$1A
		STA WSYNC
		STA COLPF2
		LDA #$1C
		STA WSYNC
		STA COLPF3
		LDA #<DLI3
		STA VDSLST
		LDA #>DLI3
		STA VDSLST+1
		PLA
		RTI
DLI3		PHA
		LDA #$26
		STA WSYNC
		STA COLPF0
		LDA #$28
		STA WSYNC
		STA COLPF1
		LDA #$2A
		STA WSYNC
		STA COLPF2
		LDA #$2C
		STA WSYNC
		STA COLPF3
		LDA #<DLI4
		STA VDSLST
		LDA #>DLI4
		STA VDSLST+1
		PLA
		RTI
DLI4		PHA
		LDA #$36
		STA WSYNC
		STA COLPF0
		LDA #$38
		STA WSYNC
		STA COLPF1
		LDA #$3A
		STA WSYNC
		STA COLPF2
		LDA #$3C
		STA WSYNC
		STA COLPF3
		LDA #<DLI5
		STA VDSLST
		LDA #>DLI5
		STA VDSLST+1
		PLA
		RTI
DLI5		PHA
		LDA #$46
		STA WSYNC
		STA COLPF0
		LDA #$48
		STA WSYNC
		STA COLPF1
		LDA #$4A
		STA WSYNC
		STA COLPF2
		LDA #$4C
		STA WSYNC
		STA COLPF3
		LDA #<DLI6
		STA VDSLST
		LDA #>DLI6
		STA VDSLST+1
		PLA
		RTI
DLI6		PHA
		LDA #$56
		STA WSYNC
		STA COLPF0
		LDA #$58
		STA WSYNC
		STA COLPF1
		LDA #$5A
		STA WSYNC
		STA COLPF2
		LDA #$5C
		STA WSYNC
		STA COLPF3
		STA WSYNC			; EXTRA TIME WASTING
		STA WSYNC			; EXTRA TIME WASTING
		STA WSYNC			; EXTRA TIME WASTING
		STA WSYNC			; EXTRA TIME WASTING
		STA WSYNC			; EXTRA TIME WASTING
		LDA #$00			; BAR
		STA HSCROL			; BAR
		LDA #<DLI7
		STA VDSLST
		LDA #>DLI7
		STA VDSLST+1
		PLA
		RTI
DLI7		PHA
		LDA HPLRCTR
		STA HSCROL
		LDA #$04
		STA WSYNC
		STA COLPF0
		LDA #$06
		STA WSYNC
		STA COLPF1
		LDA #$0F
		STA WSYNC
		STA COLPF2
		LDA #$20
		STA WSYNC
		STA COLPF3
		LDA #<DLI8
		STA VDSLST
		LDA #>DLI8
		STA VDSLST+1
		PLA
		RTI
DLI8		PHA
		LDA HMONSCR
		STA WSYNC
		STA HSCROL
		LDA #<DLI9
		STA VDSLST
		LDA #>DLI9
		STA VDSLST+1
		PLA
		RTI
DLI9		PHA
		LDA #$00
		STA WSYNC
		STA HSCROL
		LDA #<DLI1
		STA VDSLST
		LDA #>DLI1
		STA VDSLST+1
		PLA
		RTI
; -----------------------------------------

;
; DISPLAY LIST
;
		*=$0600	
				; CRAM INTO PAGE 6

DLIST		.BYTE $70				; 3
		.BYTE $70				; BLANK
		.BYTE $F0				; SETS OF 8 LINES FOR BORDER. DLI (DLI1)
;
; SCORE/BONUS DISPLAY
;
		.BYTE $55,<BONSCR,>BONSCR		; BONUS SCREEN MEMORY, ANTIC 5, LMS BONSCR, HSCROL
		.BYTE $10				; 2 BLANK LINES.
;
; BLANK LINES FOR THE TOP SECTION.
;
DLTOPJ		.BYTE $01,<DLTOPU,>DLTOPU		; VERTICAL SCROLL JUMP
DLTOPD		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
DLTOPU		.BYTE $00				; 1 BLANK LINE.
;
; THE INVADERS.
;
DLINV		.BYTE $90				; 2 BLANK LINES, DLI (DLI2)
DLINV1		.BYTE $54,$00,>INVL1M			; INVADERS LINE 1, ANTIC 4, LMS INVL1, HSCROL
		.BYTE $90				; 2 BLANK LINES, DLI (DLI3)
DLINV2		.BYTE $54,$00,>INVL2M			; INVADERS LINE 2, ANTIC 4, LMS INVL2, HSCROL
		.BYTE $90				; 2 BLANK LINES, DLI (DLI4)
DLINV3		.BYTE $54,$00,>INVL3M			; INVADERS LINE 3, ANTIC 4, LMS INVL3, HSCROL
		.BYTE $90				; 2 BLANK LINES, DLI (DLI5)
DLINV4		.BYTE $54,$00,>INVL4M			; INVADERS LINE 4, ANTIC 4, LMS INVL4, HSCROL
		.BYTE $90				; 2 BLANK LINES, DLI (DLI6)
DLINV5		.BYTE $54,$00,>INVL5M			; INVADERS LINE 5, ANTIC 4, LMS INVL4, HSCROL

;
; BLANK LINES FOR THE BOTTOM SECTION.
;
		.BYTE $01,<DLBOTU,>DLBOTU		; VERTICAL SCROLL JUMP INSTRUCTION

DLBOTU		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
DLBOTD		.BYTE $00				; 1 BLANK LINE.

;
; PLAYER DISPLAY
;
		.BYTE $80				; 1 BLANK LINE
DLPLYR		.BYTE $54,<PLRM,>PLRM			; PLAYER MOVEMENT LINE, ANTIC 4, LMS PLRM, HSCROL

;
; MOON/SCORE DISPLAY
;

DLMOON		.BYTE $80				; 1 BLANK LINE, DLI (DLI8)
DLMOON1		.BYTE $54,<MOONM1+$DC,>MOONM1		; MOON LINE 1, ANTIC 4, LMS MOONM1, HSCROL
DLMOON2		.BYTE $54,<MOONM2+$DC,>MOONM2		; MOON LINE 2, ANTIC 4, LMS MOONM2, HSCROL
DLMOON3		.BYTE $54,<MOONM3+$DC,>MOONM3		; MOON LINE 3, ANTIC 4, LMS MOONM3, HSCROL
DLMOON4		.BYTE $54,<MOONM4+$DC,>MOONM4		; MOON LINE 4, ANTIC 4, LMS MOONM4, HSCROL
		.BYTE $80				; 1 BLANK LINE, DLI (DLI9)
		.BYTE $54,<SCRM,>SCRM			; SCORE, ANTIC 4, LMS SCRM, HSCROL
		.BYTE $54,<SCRM2,>SCRM2
DLEND		.BYTE $41,<DLIST,>DLIST			; JUMP BACK TO START OF DLIST AFTER VBLANK


;
; SCREEN MEMORY BLOCKS (1 PAGE A PIECE)
;


;
; BONUS ALIEN.
;
BONSCR		*=$1000
		.BYTE $00,$00,$1C,$1E,$00,$00,$00,$00,$00,$00,$52,$53,$00,$00,$00,$00
		.BYTE $1C,$1E,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; INVADERS LINE 1
;
INVL1		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
INVL1M		.BYTE $00,$00,$00,$00,$00,$01,$02,$00,$01,$02,$00,$01,$02,$00,$01,$02
		.BYTE $00,$01,$02,$00,$01,$02,$00,$01,$02,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; INVADERS LINE 2
;
INVL2		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
INVL2M		.BYTE $00,$00,$00,$00,$00,$05,$06,$00,$05,$06,$00,$05,$06,$00,$05,$06
		.BYTE $00,$05,$06,$00,$05,$06,$00,$05,$06,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; INVADERS LINE 3
;
INVL3		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
INVL3M		.BYTE $00,$00,$00,$00,$00,$09,$0A,$00,$09,$0A,$00,$09,$0A,$00,$09,$0A
		.BYTE $00,$09,$0A,$00,$09,$0A,$00,$09,$0A,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; INVADERS LINE 4
;
INVL4		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
INVL4M		.BYTE $00,$00,$00,$00,$00,$07,$08,$00,$07,$08,$00,$07,$08,$00,$07,$08
		.BYTE $00,$07,$08,$00,$07,$08,$00,$07,$08,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; INVADERS LINE 5
;
INVL5		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
INVL5M		.BYTE $00,$00,$00,$00,$00,$0B,$0C,$00,$0B,$0C,$00,$0B,$0C,$00,$0B,$0C
		.BYTE $00,$0B,$0C,$00,$0B,$0C,$00,$0B,$0C,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; PLAYER MEMORY
;
PLRM		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$1C,$3B
		.BYTE $3C,$1E,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; MOON LINE 1
;
MOONM1		.BYTE $42,$43,$44,$42,$44,$43,$45,$46,$47,$43,$45,$46,$47,$42,$43,$45
		.BYTE $43,$45,$43,$47,$48,$45,$46,$49,$44,$42,$46,$47,$43,$45,$42,$44
		.BYTE $42,$44,$46,$45,$43,$42,$45,$47,$46,$42,$43,$44,$45,$46,$47,$48
		.BYTE $49,$45,$44,$43,$46,$48,$47,$44,$43,$45,$46,$42,$47,$48,$45,$44
		.BYTE $43,$46,$47,$43,$42,$44,$46,$45,$46,$47,$48,$49,$45,$43,$42,$47
		.BYTE $42,$46,$45,$43,$44,$45,$46,$47,$48,$43,$45,$44,$42,$46,$47,$42
		.BYTE $43,$42,$47,$46,$45,$42,$48,$46,$45,$44,$47,$49,$43,$44,$46,$48
		.BYTE $46,$44,$43,$48,$49,$42,$43,$44,$45,$46,$43,$48,$49,$43,$42,$46
		.BYTE $45,$42,$44,$46,$43,$47,$48,$42,$47,$42,$45,$43,$42,$47,$45,$43
		.BYTE $43,$44,$46,$47,$43,$45,$46,$47,$48,$42,$45,$46,$43,$46,$47,$42
		.BYTE $46,$43,$42,$48,$47,$46,$45,$46,$48,$43,$42,$47,$43,$44,$45,$46
		.BYTE $42,$47,$45,$49,$46,$42,$43,$44,$45,$46,$47,$48,$49,$42,$44,$47
		.BYTE $46,$43,$42,$48,$45,$44,$42,$47,$49,$45,$42,$45,$47,$45,$42,$48
		.BYTE $43,$45,$47,$46,$44,$42,$45,$48,$43,$42,$48,$49,$42,$48,$47,$42
		.BYTE $46,$44,$42,$47,$45,$45,$46,$47,$48,$49,$43,$45,$47,$45,$46,$48
		.BYTE $45,$43,$42,$48,$46,$43,$49,$46,$45,$43,$42,$47,$48,$49,$43,$44

;
; MOON LINE 2
;
MOONM2		.BYTE $52,$54,$53,$4A,$4B,$55,$52,$57,$52,$52,$56,$55,$56,$55,$54,$54
		.BYTE $57,$56,$54,$55,$54,$54,$55,$56,$56,$55,$53,$54,$54,$53,$55,$53
		.BYTE $55,$57,$56,$54,$52,$52,$57,$52,$57,$57,$51,$52,$52,$52,$52,$52
		.BYTE $54,$54,$52,$52,$56,$56,$53,$51,$53,$53,$57,$56,$56,$56,$56,$55
		.BYTE $52,$52,$54,$53,$55,$55,$52,$55,$56,$52,$53,$54,$54,$57,$55,$56
		.BYTE $56,$53,$55,$55,$52,$52,$57,$54,$53,$52,$52,$53,$52,$53,$52,$52
		.BYTE $57,$54,$56,$57,$53,$51,$52,$53,$57,$51,$55,$55,$53,$52,$56,$53
		.BYTE $53,$55,$57,$53,$55,$55,$53,$52,$52,$56,$56,$52,$57,$51,$54,$54
		.BYTE $52,$56,$55,$57,$53,$56,$54,$58,$52,$53,$52,$55,$55,$57,$57,$55
		.BYTE $57,$57,$54,$55,$52,$57,$55,$57,$53,$52,$56,$57,$52,$55,$55,$56
		.BYTE $53,$54,$53,$53,$55,$53,$57,$56,$54,$51,$54,$54,$53,$53,$53,$57
		.BYTE $52,$52,$52,$52,$56,$52,$52,$52,$55,$56,$52,$52,$56,$57,$52,$52
		.BYTE $57,$56,$54,$56,$57,$55,$57,$56,$56,$53,$53,$55,$55,$53,$56,$53 
		.BYTE $55,$55,$56,$54,$54,$54,$53,$57,$57,$52,$56,$53,$53,$53,$53,$54
		.BYTE $53,$52,$55,$52,$52,$52,$58,$55,$54,$56,$52,$56,$53,$55,$52,$55
		.BYTE $52,$57,$53,$51,$54,$53,$54,$52,$56,$51,$57,$55,$52,$53,$56,$52

;
; MOON LINE 3
;
MOONM3		.BYTE $52,$53,$55,$4C,$4D,$57,$54,$52,$54,$52,$53,$54,$55,$54,$55,$55
		.BYTE $54,$54,$55,$54,$55,$54,$53,$53,$55,$55,$4E,$4F,$56,$55,$54,$54
		.BYTE $56,$52,$56,$52,$56,$52,$55,$56,$52,$52,$55,$52,$54,$52,$53,$52
		.BYTE $57,$56,$54,$55,$52,$55,$56,$54,$53,$53,$56,$53,$52,$53,$51,$54
		.BYTE $52,$54,$52,$56,$53,$53,$57,$52,$55,$56,$57,$56,$53,$56,$55,$56
		.BYTE $53,$53,$54,$54,$54,$57,$55,$55,$53,$57,$52,$57,$55,$55,$54,$54
		.BYTE $54,$52,$53,$53,$55,$56,$52,$56,$56,$55,$53,$54,$56,$57,$52,$55
		.BYTE $55,$55,$55,$57,$56,$55,$51,$54,$57,$54,$54,$52,$53,$55,$53,$52
		.BYTE $56,$54,$53,$52,$52,$54,$53,$53,$53,$53,$55,$53,$52,$53,$54,$54
		.BYTE $57,$52,$55,$53,$53,$53,$56,$52,$52,$52,$56,$54,$54,$52,$56,$57
		.BYTE $53,$53,$52,$55,$54,$52,$54,$55,$54,$55,$53,$56,$56,$53,$54,$55
		.BYTE $54,$54,$51,$56,$55,$54,$52,$54,$55,$56,$52,$57,$55,$55,$53,$54
		.BYTE $52,$55,$54,$54,$56,$55,$51,$53,$52,$54,$54,$55,$53,$56,$52,$52
		.BYTE $56,$56,$55,$53,$57,$56,$56,$52,$53,$53,$56,$54,$52,$54,$52,$53
		.BYTE $57,$54,$57,$52,$52,$57,$52,$54,$55,$52,$57,$53,$54,$52,$51,$57
		.BYTE $52,$56,$54,$53,$56,$52,$53,$55,$56,$55,$52,$54,$56,$53,$52,$54

;
; MOON LINE 4
;
MOONM4		.BYTE $53,$55,$56,$52,$55,$55,$53,$55,$53,$55,$56,$53,$53,$55,$56,$55
		.BYTE $54,$54,$57,$53,$56,$54,$54,$54,$54,$54,$50,$51,$54,$53,$54,$53
		.BYTE $55,$53,$54,$56,$54,$53,$55,$53,$56,$53,$52,$53,$52,$54,$53,$52
		.BYTE $52,$56,$53,$54,$57,$52,$56,$56,$52,$52,$51,$52,$54,$56,$52,$56
		.BYTE $53,$54,$52,$53,$55,$56,$54,$57,$53,$56,$53,$56,$56,$55,$56,$54
		.BYTE $56,$53,$53,$52,$54,$55,$52,$55,$57,$54,$52,$53,$53,$54,$54,$52
		.BYTE $57,$52,$56,$53,$52,$54,$56,$53,$55,$57,$55,$53,$54,$52,$53,$53
		.BYTE $55,$55,$55,$55,$53,$53,$55,$54,$56,$54,$56,$56,$57,$53,$54,$57
		.BYTE $54,$56,$53,$53,$54,$52,$53,$52,$54,$53,$52,$53,$54,$57,$56,$55
		.BYTE $52,$54,$54,$52,$57,$55,$54,$54,$53,$52,$57,$56,$53,$55,$54,$54
		.BYTE $53,$53,$52,$54,$55,$56,$57,$56,$52,$56,$54,$52,$52,$52,$54,$53
		.BYTE $54,$52,$51,$56,$56,$55,$56,$54,$56,$51,$52,$56,$57,$54,$52,$52
		.BYTE $56,$53,$53,$52,$53,$54,$52,$53,$55,$55,$57,$52,$55,$56,$53,$57
		.BYTE $55,$56,$56,$53,$52,$53,$53,$56,$54,$57,$55,$54,$56,$57,$55,$54
		.BYTE $52,$54,$57,$56,$54,$57,$57,$54,$53,$55,$53,$57,$53,$55,$56,$53
		.BYTE $53,$52,$53,$55,$57,$54,$52,$57,$52,$53,$52,$53,$54,$53,$53,$52

;
; SCORE DISPLAY
;
SCRM		.SBYTE "    0000000000            0000000000"
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; SCORE DISPLAY
;
SCRM2		.SBYTE "    1UP :; x 3            2UP :; x 3"
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; RUN ADDRESS
;
		*=$02E0
		.BYTE <TOP,>TOP
