;
; INVADERS PHASER TEST FOR THE PLAYER. T10PLMIS
;

		.INCLUDE atariequ.asm
		.INCLUDE ../font1.asm

; 
; CONSTANTS
;
DIRLEFT			= $00			; GO LEFT
DIRRIGHT		= $01			; GO RIGHT
MAXINVLEFT		= $75    		; MAXIMUM LMS COUNTER FOR LEFT EXTREME AT START
MAXINVRIGHT		= $6D			; MAXIMUM LMS COUNTER FOR RIGHT EXTREME AT START
INVVSCRUNIT		= $04			; NUMBER OF SCAN LINES TO SCROLL FOR A VERTICAL MARCH.

HSCRCTR			= $80			; HORIZONTAL FINE SCROLL COUNTER
HPLRSCR			= $81			; HORIZONTAL PLAYER FINE SCROLL COUNTER
HPLRDIR			= $82			; PLAYER LEFT (0) OR RIGHT(1), BIT 2 DETERMINES IF JOYSTICK IS ACTIVE
HPLRLMS			= $83			; PLAYER LMS INSTRUCTION
HMONSCR			= $84			; MOON FINE SCROLL HSCROL
HMONLMS			= $85			; MOON LMS SCROLL
HINVDIR			= $86			; INVADERS DIRECTION
HINVSCR			= $87			; INVADERS SCROLL REGISTER
HINVLMS			= $88			; INVADERS LMS COARSE SCROLL
HINVMXL			= $89			; INVADERS LMS MAX LEFT
HINVMXR			= $8A			; INVADERS LMS MAX RIGHT
VINVMXB			= $8B			; INVADERS DLIST OFFSET MAX BOTTOM
VINVDIR			= $8C			; INVADERS MARCH DOWN?
VINVSCRT		= $8D			; CURRENT INVADERS VERTICAL SCROLL (DLIST) TOP
VINVSCRB		= $8E			; CURRENT INVADERS VERTICAL SCROLL (DLIST) BOTTOM
VINVSCRU		= $8F			; CURRENT INVADERS VERTICAL SCROLL UNIT
VKSTACT			= $90			; SHOULD STARFIELD KERNEL BE ACTIVE?
PMACT			= $91			; PLAYER MISSILE ACTIVE?
PMHPOS			= $92			; CURRENT PLAYER MISSILE HORIZONTAL POSITION
PMVPOS			= $93			; CURRENT PLAYER MISSILE VERTICAL POSITION
KSTARO			= $94			; STARFIELD KERNEL X OFFSET.

		*=$0700
	
TOP		JMP START

;
; TABLES
;
	
START		CLD

;
; INITIALIZE THE DISPLAY REGISTERS.
;
INITVALS	JSR KSINIT			; INITIALISE THE STAR TABLE.
		LDA #$00			; INITIALISE THE SCROLL REGISTERS
		STA HMONSCR			; AND PLAYER STATE REGISTERS.
		STA HINVSCR			; 
		STA VINVSCRU			;
		STA HINVDIR			; RESET INVADERS HORIZONTAL DIRECTION
		STA VINVDIR			; RESET INVADERS MARCH TO INACTIVE.
		STA HPLRSCR			; RESET PLAYER SCROLL
		STA HPLRDIR			; RESET PLAYER DIRECTION BITS TO INACTIVE AND LEFT.
		STA VKSTACT			; SET STARFIELD TO INACTIVE 
		STA KSTARO			; SET KERNEL STAR OFFSET.
		LDA #MAXINVLEFT			; SET THE INITIAL MAX LEFT EXTREME
		STA HINVMXL			;
		LDA #MAXINVRIGHT		; SET THE INITIAL MAX RIGHT EXTREME
		STA HINVMXR			; 
		LDA #$01			; GO RIGHT.
		STA HINVDIR			; INITIALISE THE DIRECTION REGISTERS
		LDA #$89			; INITIALISE THE INVADERS LMS COUNTER
		STA HINVLMS			; 
		LDA #$DC			; INITIALISE THE MOON LMS COUNTER.
		STA HMONLMS			;
		LDA #<DLTOPU+1			; INITIALISE THE INVADERS VERTICAL SCROLL COUNTER (DLIST) TOP
		STA VINVSCRT			;
		LDA #<DLTOPD+1			; INITIALISE THE INVADERS VERTICAL SCROLL COUNTER MAX (DLIST)
		STA VINVMXB			; 
		LDA #<DLBOTU+1			; INITIALISE THE INVADERS VERTICAL SCROLL COUNTER (DLIST) BOTTOM
		STA VINVSCRB			;
		LDA DLPLYR+1			; INITIALISE THE PLAYER SCREEN MEMORY.
		STA HPLRLMS			;
		LDA #$4D			; STARFIELD COLOR.
		STA PCOLR1			; 
;
; SET UP PLAYFIELD/PLAYER-MISSILE DMA
;

SETPF		LDA #$3D		; NARROW, PLAYER, MISSILE, 1 LINE P/M, INSTRUCTION FETCH DMA ($3D)
		STA SDMCTL		;
SETPM		LDA #$03		; PLAYER/MISSILE DMA TO GTIA
		STA GRACTL		;
		LDA #$04		; SET P/M PRIORITY #3
		STA GPRIOR

;
; SET DISPLAY LIST
;

SETDL		LDA #<DLIST		; SET LO BYTE OF DISPLAY LIST
		STA SDLSTL		;
		LDA #>DLIST		; SET HI BYTE OF DISPLAY LIST
		STA SDLSTL+1		;

;
; SET DLI VECTOR
;

SETDLI		LDA #<DLI1
		STA VDSLST
		LDA #>DLI1
		STA VDSLST+1
		LDA #$C0
		STA NMIEN

;
; SET UP CHARACTER SET
;

SETCHR		LDA #>FONT1
		STA CHBAS

;
; SET UP THE PMBASE AREA IN MEMORY
;
SETPMB		LDA #>PMB
		STA PMBASE

;
; SET UP THE VBI ROUTINE
; 
SETVBI		LDY #<VBIRT				; LOW BYTE
		LDX #>VBIRT				; HI BYTE
		LDA #$06				; IMMEDIATE VBI
		JSR SETVBV

SETVBID		LDY #<VBIDF				;
		LDX #>VBIDF				;
		LDA #$07				; DEFERRED VBI
		JSR SETVBV				;

;
; THE MAIN GAME LOOP
;
BEGLOOP		
VKSCHK		LDA VKSTACT				; STAR FIELD KERNEL NEED TO BE ACTIVE?
		CMP #$01				; ARE WE ACTIVE?
		BNE CHKGAMOVR				; NO, CHECK FOR GAME OVER.
		JSR KSTARF				; JUMP TO THE STARFIELD KERNEL.
CHKPMA		LDA PMACT				; CHECK PM ACT
		CMP #$01				; IS PM ACT?
		BNE CHKGAMOVR				; NO, CHECK FOR GAME OVER
CHKGAMOVR	LDA VINVSCRT				; ARE INVADERS AT THE BOTTOM? 
		CMP VINVMXB				;
		BEQ GAMEOVER				; YES, GAME OVER!
CHKD		LDA HINVDIR				; NO, CHECK INVADERS DIRECTION
		CMP #$01				; GOING RIGHT?
		BEQ CHKR				; YES, CHECK IF WE ARE GOING ALL THE WAY RIGHT?
CHKL		LDA HINVLMS				; GET THE CURRENT LMS COUNTER
		CMP HINVMXL				; ARE WE ALL THE WAY LEFT?
		BNE ENDLOOP				; NO, GO TO THE END OF THE LOOP.
GORIGHT		LDA #$01				; SET DIRECTION TO RIGHT
		STA HINVDIR				; AND STORE IT.
		JMP MARCHDWN				; AND GO TO THE END OF THE LOOP.
CHKR		LDA HINVLMS				; 
		CMP HINVMXR				; ARE WE ALL THE WAY RIGHT?
		BNE ENDLOOP				; NO...
GOLEFT		LDA #$00				; SET DIRECTION TO LEFT
		STA HINVDIR				; 
		JMP MARCHDWN				;
MARCHDWN	LDA #$01				; SET THE INVADERS TO MARCH DOWN
		STA VINVDIR				;
		JMP ENDLOOP				; AND GO TO END OF LOOP.
ENDLOOP		JMP BEGLOOP				; AND GO BACK TO BEGINNING.
GAMEOVER	JMP GAMEOVER				; GAME OVER!

; ------ END MAIN LINE CODE ---------------

;
; VBI ROUTINES - IMMEDIATE
;
VBIRT		LDA #$00				; KILL THE ATTRACT! 
		STA ATRACT				;
		LDA RTCLOK+2				; REALTIME CLOCK SAMPLING
		AND #$FF				; 8 VBI'S
		BNE VBISF				; NOT READY YET, CHECK FOR SHIP FIRING.
		INC KSTARO				; INCREMENT KERNEL STAR FIELD OFFSET.
VBISF		LDA PMACT				; SHIP MISSLE ACTIVE?
		CMP #$01				; 
		BNE VBPLRC				; NO, CHECK TO SEE IF PLAYER NEEDS TO BE MOVED.
		DEC PMVPOS				; DECREMENT PLAYER VERTICAL POSITION.
		BEQ VBPMRST				; AT ZERO? RESET VALUES AND CONTINUE ON.
VBUPDPM		LDY PMVPOS				; LOAD Y POSITION WITH VERTICAL POSITION OF MISSILE.
		LDX PMHPOS				; LOAD X POSITION WITH HORIZONTAL POSITION OF MISSILE.
		LDA #$01				; LOAD A WITH WHICH MISSILE TO MOVE (PLAYER)
		JSR SVBIMM				; JUMP TO MISSILE MOVE SUBROUTINE.
		JMP VBPLRC				; AND CONTINUE THROUGH THE ROUTINE.
VBPMRST		LDA #$00				; TURN OFF TRIGGER MOVEMENT.
		STA PMACT				; AND TURN OFF TRIGGER FLAG.
		LDA #$03				; AND UNLATCH THE TRIGGER, IT CAN FIRE AGAIN.
		STA GRACTL				; 
VBPLRC		LDA RTCLOK+2				; TIME TO MOVE THE PLAYER? 
		AND #$01				;
		BNE VBINVMC				; COME BACK HERE
VBPLR		CLC
		LDA HPLRDIR				; CHECK PLAYER DIRECTION.
		CMP #$03				; RIGHT?
		BEQ VBPLRR				; YES, GO RIGHT.
		CMP #$02				; LEFT? 
		BEQ VBPLRL				; YES, GO LEFT.
		JMP VBINVMC				; NO MOVEMENT, GO TO MARCH.
VBPLRR		LDA HPLRLMS				; GRAB THE CURRENT PLAYER LMS
		CMP #$60				; ARE WE ALL THE WAY RIGHT?
		BCC VBPLRRE				; YES, DON'T GO RIGHT ANYMORE!
VBPLRRS		LDA HPLRSCR				; GRAB THE PLAYER FINE SCROLL
		CMP #$0F				; ALL THE WAY RIGHT?
		BEQ VBPLRRLMS				; YES, UPDATE THE PLAYER LMS
		INC HPLRSCR				; OTHERWISE, INCREMENT THE PLAYER SCROLL
		JMP VBINVMC				; AND START THE VERTICAL MARCH CHECK.
VBPLRRLMS	DEC HPLRLMS				; DECREMENT THE LMS COUNTER FOR THE PLAYER GRAPHIC.
		DEC HPLRLMS				;
		DEC HPLRLMS				;
		DEC HPLRLMS				;
		LDA HPLRLMS				; LOAD THE LMS COUNTER,
		STA DLPLYR+1				; AND STORE IT INTO THE DISPLAY LIST.
		LDA #$00				; RESET THE SCROLL REGISTER
		STA HPLRSCR				;
VBPLRRE		JMP VBINVMC				; AND CONTINUE ONWARD TO THE VERTICAL MARCH.	
VBPLRL		LDA HPLRLMS				;
		CMP #$80				;
		BCS VBPLRLE				;
VBPLRLS		LDA HPLRSCR				;
		CMP #$00				; ALL THE WAY LEFT?
		BEQ VBPLRLLMS				; YES, UPDATE THE PLAYER LMS
		DEC HPLRSCR				; OTHERWISE, DECREMENT THE PLAYER SCROLL.
		JMP VBINVMC				; AND START THE VERTICAL MARCH CHECK.
VBPLRLLMS	INC HPLRLMS				; INCREMENT THE LMS COUNTER
		INC HPLRLMS				;
		INC HPLRLMS				;
		INC HPLRLMS				;
		LDA HPLRLMS				;
		STA DLPLYR+1				;
		LDA #$0F				;
		STA HPLRSCR				;
VBPLRLE		JMP VBINVMC				;
VBINVMC		LDA RTCLOK+2				; CHECK FOR VERTICAL MARCH.
		AND #$03				;
		BNE VBCHKDR				;
		LDA VINVDIR				; ARE WE MARCHING DOWNWARD?
		CMP #$01				;
		BNE VBCHKDR				; NO, DO THE HORIZONTAL MOTION, INSTEAD.
VBINVMH		LDA VINVSCRT				; FIND OUT IF WE CAN GO DOWN AT ALL?
		CMP VINVMXB				;
		BNE VBINVMAR				;
		JMP VBUPDMO				; NO, UPDATE THE MOON.
VBINVMAR	INC VINVSCRU				; INCREMENT THE VERTICAL SCROLL COUNTER.
		DEC VINVSCRT				; GO ONE DOWN.
		LDA VINVSCRT				;
		STA DLTOPJ+1				; AND STORE IT IN THE DISPLAY LIST.
		INC VINVSCRB				;
		LDA VINVSCRB				;
		STA DLBOTJ+1				; AND DO THE SAME FOR THE BOTTOM BLANKS.
		LDA VINVSCRU				; CHECK SCROLL COUNTER,
		CMP #INVVSCRUNIT			; ARE WE DONE VERTICAL SCROLLING?
		BNE VBUPDMO				; NO, FORGET THE HORIZONTAL, AND UPDATE MOON GRAPHIC.
VBINVMR		LDA #$00				; RESET THE SCROLL UNIT.
		STA VINVSCRU				;
		STA VINVDIR				; AND THE DIRECTION BIT.
		JMP VBUPDMO				; DO NOT UPDATE HORIZONTAL POSITION DURING THIS TIME.  
VBCHKDR		LDA RTCLOK+2				;
		AND #$07				;
		BNE VBUPDMO				; NOT READY YET, SKIP AHEAD.
VBINVDIR	LDA HINVDIR				; FIND OUT IF WE NEED TO BE GOING LEFT OR RIGHT?
		CMP #$00				;
		BNE VBINVRIG				; YES, GO RIGHT.
VBINVLEF	LDA HINVSCR				; CHECK SCROLL REGISTER
		CMP #$00				; ALL THE WAY LEFT?
		BEQ VBINVLLMS				; YES, DO A COARSE SCROLL LEFT.
		DEC HINVSCR				; SCROLL LEFT.
		JMP VBUPDMO				; CONTINUE THE VBI ROUTINE.
VBINVLLMS	INC HINVLMS				; DECREMENT THE LMS SCROLL
		INC HINVLMS				;
		INC HINVLMS				;
		INC HINVLMS				;
		LDA HINVLMS				; GRAB THE LMS OFFSET
		STA DLINV1+1				; UPDATE THE INVADERS LMS
		STA DLINV2+1				;
		STA DLINV3+1				;
		STA DLINV4+1				;
		STA DLINV5+1				;
		LDA #$0F				; RESET THE SCROLL REGISTER.
		STA HINVSCR				;
		JMP VBUPDMO				; CONTINUE ON...
VBINVRIG	LDA HINVSCR				; CHECK SCROLL REGISTER
		CMP #$0F				; ALL THE WAY RIGHT?
		BEQ VBINVRLMS				; YES, DO A COARSE SCROLL RIGHT.
		INC HINVSCR				; SCROLL RIGHT
		JMP VBUPDMO				; CONTINUE THE VBI ROUTINE
VBINVRLMS	DEC HINVLMS				; INCREMENT THE LMS SCROLL
		DEC HINVLMS				;
		DEC HINVLMS				;
		DEC HINVLMS				;
		LDA HINVLMS				; GRAB THE LMS OFFSET
		STA DLINV1+1				; UPDATE THE INVADERS LMS
		STA DLINV2+1				;
		STA DLINV3+1				;
		STA DLINV4+1				;
		STA DLINV5+1				;
		LDA #$00				; RESET THE SCROLL REGISTER
		STA HINVSCR				;
		JMP VBUPDMO				; AND CONTINUE ON...
VBUPDMO		LDA RTCLOK+2				; TRIGGER EVERY 16 VBLANKS
		AND #$01				;
		BNE VBDON				;
VBIHSCRL	LDA HMONSCR				; GRAB CURRENT SCROLL REGISTER
		CMP #$0F
		BEQ VBILMS				; YES, INCREMENT THE LMS
		INC HMONSCR				; INCREMENT THE MOON SCROLLER
		JMP VBDON				; AND COMPLETE THE ROUTINE.
VBILMS		DEC HMONLMS				; DECREMENT THE LMS SCROLL
		DEC HMONLMS				;
		DEC HMONLMS				;
		DEC HMONLMS				;
		LDA HMONLMS				;
		AND #$7F				; MASK OFF THE 8TH BIT.
		STA DLMOON1+1				; UPDATE THE COARSE SCROLL
		STA DLMOON2+1				;
		STA DLMOON3+1				;
		STA DLMOON4+1				;
		LDA #$00				;
		STA HMONSCR				;
		JMP VBDON				;
VBDON		JMP SYSVBV				; AND COMPLETE THE VBI ROUTINE.

;
; VBI SUBROUTINES - IMMEDIATE
;

;
; MISSILE MOVE
; A = MISSILE TO MOVE, 1 = PLAYER, 2 = ENEMY #1, 3 = ENEMY #2
; X = X POSITION OF MISSILE IN COLOR CLOCKSMAXINVLEFT
; Y = Y POSITION OF MISSILE IN SCAN LINES.
;
SVBIMM
		CMP #$01				; PLAYER MOVE?
		BEQ SVBIMMP				; YES, MOVE PLAYER MISSILE
		CMP #$02				; ENEMY #1 MOVE?
		BEQ SVBIMME1				; YES, MOVE ENEMY #1 MISSILE
		CMP #$03				; ENEMY #2 MOVE?
		BEQ SVBIMME2				; YES, MOVE ENEMY #2 MISSILE 
SVBIMMP		STX HPOSM1				; STORE X POS OF PLAYER.
		INY					; FIRST INCREMENT Y TO ERASE THE BIT BELOW
		LDA PMBMS,Y				; GRAB IT.
		EOR #$04				; ERASE IT.
		STA PMBMS,Y				; STORE IT.
		DEY					; AND DECREMENT BACK TO WHERE WE WERE.
		LDX #$06				; 6 PIXELS HIGH PHOTONS.
SVBIMMPL	LDA PMBMS,Y				; LOAD THE CURRENT BYTE
		ORA #$04				; TURN ON THE APPROPRIATE BITS.
		STA PMBMS,Y				; AND STORE IT.
		DEY					; DECREMENT THE Y POS.
		DEX					; DECREMENT THE X (WHICH IS USED FOR MISSILE WIDTH.)
		BNE SVBIMMPL				; NOT DONE YET, LOOP BACK.
		JMP SVBIMDON				; DONE? QUIT THE SUBROUTINE.
SVBIMME1
SVBIMME2
SVBIMDON	RTS					; RETURN FROM SUBROUTINE.

;
; VBI ROUTINES - DEFERRED
;
VBIDF							; START VBI ROUTINE.
		LDA PMACT				; CHECK FOR ACTIVE PLAYER MISSILE
		CMP #$01				; ARE WE?
		BEQ VBDCHKS				; YES IT IS ACTIVE, BYPASS MISSILE RESET.
		LDA #$07				; LATCH THE TRIGGERS.
		STA GRACTL				;
VBDCHKT		LDA STRIG0				; GRAB THE TRIGGER
		CMP #$00				; PRESSED?
		BNE VBDCHKS				; NO, PROCEED TO CHECKING STICK.
		LDA #$01				; YES, SET PLAYER MISSILE TO BE ACTIVE.
		STA PMACT				; AND STORE IT.
		LDA HPLRLMS				; TEMP: SET X POSITION TO 50 COLORCLOCKS
		STA PMHPOS				; TEMP: AND STORE IN PLAYER X POSITION
		LDA #$AE				; TEMP: SET Y POSITION TO 160 SCAN LINES DOWN.
		STA PMVPOS				; TEMP: AND STORE IN PLAYER Y POSITION
VBDCHKS		LDA STICK0				; GRAB JOYSTICK.
		CMP #$0F				; JOYSTICK MOVING AT ALL?
		BNE VBSTKMV				; YES, STICK IS MOVING,
		LDA #$00				; SET THE PLAYER TO COMPLETELY STILL.
		STA HPLRDIR				; 
		JMP VBDDON				; AND COMPLETE THE ROUTINE
VBSTKMV		CMP #$07				; GOING RIGHT?
		BEQ VBDPGR				; YES, GO RIGHT.
		CMP #$0B				; GOING LEFT?
		BEQ VBDPGL				; YES, GO LEFT.
		JMP VBDDON				; JUMP TO END OF ROUTINE.
VBDPGR		LDA #$03				; GO RIGHT, SET PLAYER MOVING AND RIGHT
		STA HPLRDIR				;
		JMP VBDDON				;
VBDPGL		LDA #$02				; GO LEFT, SET PLAYER MOVING AND LEFT
		STA HPLRDIR
		JMP VBDDON				;
VBDDON		JMP XITVBV				; EXIT FROM THE DEFERRED VBI ROUTINE.

;
; THE STARFIELD KERNEL INITIALISATION.
; GRAB RANDOM NUMBERS, MASK OFF THE NUMBERS WE DON'T WANT
; AND FILL THE TABLE.
;
KSINIT		LDX #$00				; INITIALISE COUNTER
KSILOP		LDA RANDOM				; GRAB RANDOM NUMBER
		CMP #$40				; START AT $40 (64 COLOR CLOCKS OVER)
		BCC KSILOP				; TOO MUCH, GRAB ANOTHER #
		CMP #$C0				; COMPARE AGAINST $C0 (192 COLOR CLOCKS OVER.)
		BCS KSILOP				; TOO MUCH, GRAB ANOTHER # 
		STA KSTARTBL,X				; STORE THE # IN TABLE.
		INX					; MOVE FORWARD IN THE TABLE.
		BNE KSILOP				; CONTINUE THE LOOP, OR....
		RTS					; RETURN FROM THE SUBROUTINE.

;
; THE STARFIELD KERNEL CALLED AT BEGINNING OF GAME LOOP.
;
KSTARF		STA WSYNC
		LDA #$0C				; TEMP: PICK A RANDOM COLOR
		STA COLPM0				; AND STORE IT IN PLAYER/MISSILE REGISTER 0 (STARFIELD)
		LDX VCOUNT				; LOAD A LINE BASED ON VCOUNT
		LDA KSTARTBL,X				; SET IT INTO THE ACCUMULATOR
		ADC KSTARO				; ADD OFFSET.
		STA HPOSM0				; AND SET TO HORIZONTAL POSITION.
		STA WSYNC				; DO ANOTHER WSYNC
		LDA #$00				; ZERO POSITION
		STA HPOSM0				; STORE IT.
		;sta wsync
		
		
		RTS					; RETURN FROM ROUTINE.

;
; THE STARFIELD KERNEL TABLE.
;
KSTARTBL	.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; MISSILE TABLE (THIS MAY BE SOMETHING BETTER IN THE FUTURE)
;
TBLPM		.BYTE $04,$04,$04,$04,$04

;
; DLI ROUTINES
;

DLI1		PHA
		STA WSYNC
		LDA #$B6
		STA WSYNC
		STA COLPF0
		LDA #$B8
		STA WSYNC
		STA COLPF1
		LDA #$BA
		STA WSYNC
		STA COLPF2
		LDA #$BC
		STA WSYNC
		STA COLPF3
		LDA #$01				; TURN ON STARFIELD KERNEL.
		STA VKSTACT				; 
		LDA #<DLI2
		STA VDSLST
		LDA #>DLI2
		STA VDSLST+1
		PLA
		RTI
DLI2		PHA
		LDA HINVSCR			
		STA HSCROL			      
		LDA #$14
		STA WSYNC
		STA COLPF0
		LDA #$16
		STA WSYNC
		STA COLPF1
		LDA #$1A
		STA WSYNC
		STA COLPF2
		LDA #$1C
		STA WSYNC
		STA COLPF3
		LDA #<DLI3
		STA VDSLST
		LDA #>DLI3
		STA VDSLST+1
		PLA
		RTI
DLI3		PHA
		LDA #$24
		STA WSYNC
		STA COLPF0
		LDA #$26
		STA WSYNC
		STA COLPF1
		LDA #$2A
		STA WSYNC
		STA COLPF2
		LDA #$2C
		STA WSYNC
		STA COLPF3
		LDA #<DLI4
		STA VDSLST
		LDA #>DLI4
		STA VDSLST+1
		PLA
		RTI
DLI4		PHA
		LDA #$34
		STA WSYNC
		STA COLPF0
		LDA #$36
		STA WSYNC
		STA COLPF1
		LDA #$3A
		STA WSYNC
		STA COLPF2
		LDA #$3C
		STA WSYNC
		STA COLPF3
		LDA #<DLI5
		STA VDSLST
		LDA #>DLI5
		STA VDSLST+1
		PLA
		RTI
DLI5		PHA
		LDA #$44
		STA WSYNC
		STA COLPF0
		LDA #$46
		STA WSYNC
		STA COLPF1
		LDA #$4A
		STA WSYNC
		STA COLPF2
		LDA #$4C
		STA WSYNC
		STA COLPF3
		LDA #<DLI6
		STA VDSLST
		LDA #>DLI6
		STA VDSLST+1
		PLA
		RTI
DLI6		PHA
		LDA #$54
		STA WSYNC
		STA COLPF0
		LDA #$56
		STA WSYNC
		STA COLPF1
		LDA #$5A
		STA WSYNC
		STA COLPF2
		LDA #$5C
		STA WSYNC
		STA COLPF3
		STA WSYNC			; EXTRA TIME WASTING
		STA WSYNC			; EXTRA TIME WASTING
		STA WSYNC			; EXTRA TIME WASTING
		STA WSYNC			; EXTRA TIME WASTING
		STA WSYNC			; EXTRA TIME WASTING
		LDA #$00			; BAR
		STA HSCROL			; BAR
		LDA #<DLI7
		STA VDSLST
		LDA #>DLI7
		STA VDSLST+1
		PLA
		RTI
DLI7		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7A
		STA VDSLST
		LDA #>DLI7A
		STA VDSLST+1
		PLA
		RTI
DLI7A		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7B
		STA VDSLST
		LDA #>DLI7B
		STA VDSLST+1
		PLA
		RTI
DLI7B		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7C
		STA VDSLST
		LDA #>DLI7C
		STA VDSLST+1
		PLA
		RTI
DLI7C		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7D
		STA VDSLST
		LDA #>DLI7D
		STA VDSLST+1
		PLA
		RTI
DLI7D		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7E
		STA VDSLST
		LDA #>DLI7E
		STA VDSLST+1
		PLA
		RTI
DLI7E		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7F
		STA VDSLST
		LDA #>DLI7F
		STA VDSLST+1
		PLA
		RTI
DLI7F		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7G
		STA VDSLST
		LDA #>DLI7G
		STA VDSLST+1
		PLA
		RTI
DLI7G		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7H
		STA VDSLST
		LDA #>DLI7H
		STA VDSLST+1
		PLA
		RTI
DLI7H		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7I
		STA VDSLST
		LDA #>DLI7I
		STA VDSLST+1
		PLA
		RTI
DLI7I		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7J
		STA VDSLST
		LDA #>DLI7J
		STA VDSLST+1
		PLA
		RTI
DLI7J		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7K
		STA VDSLST
		LDA #>DLI7K
		STA VDSLST+1
		PLA
		RTI
DLI7K		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7L
		STA VDSLST
		LDA #>DLI7L
		STA VDSLST+1
		PLA
		RTI
DLI7L		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7M
		STA VDSLST
		LDA #>DLI7M
		STA VDSLST+1
		PLA
		RTI
DLI7M		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7N
		STA VDSLST
		LDA #>DLI7N
		STA VDSLST+1
		PLA
		RTI
DLI7N		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7O
		STA VDSLST
		LDA #>DLI7O
		STA VDSLST+1
		PLA
		RTI
DLI7O		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7P
		STA VDSLST
		LDA #>DLI7P
		STA VDSLST+1
		PLA
		RTI
DLI7P		PHA
		LDA RANDOM
		STA WSYNC
		STA COLPF2
		LDA #<DLI7Z
		STA VDSLST
		LDA #>DLI7Z
		STA VDSLST+1
		PLA
		RTI
DLI7Z		PHA
		LDA #$00			; TURN OFF STARFIELD KERNEL
		STA VKSTACT			; 
		LDA HPLRSCR
		STA HSCROL
		LDA #$04
		STA WSYNC
		STA COLPF0
		LDA #$06
		STA WSYNC
		STA COLPF1
		LDA #$0F
		STA WSYNC
		STA COLPF2
		LDA #$20
		STA WSYNC
		STA COLPF3
		LDA #<DLI8
		STA VDSLST
		LDA #>DLI8
		STA VDSLST+1
		PLA
		RTI
DLI8		PHA
		LDA HMONSCR
		STA WSYNC
		STA HSCROL
		LDA #<DLI9
		STA VDSLST
		LDA #>DLI9
		STA VDSLST+1
		PLA
		RTI
DLI9		PHA
		LDA #$00
		STA WSYNC
		STA HSCROL
		LDA #<DLI1
		STA VDSLST
		LDA #>DLI1
		STA VDSLST+1
		PLA
		RTI
; -----------------------------------------

;
; DISPLAY LIST
;
		*=$0600	
				; CRAM INTO PAGE 6

DLIST		.BYTE $70				; 3
		.BYTE $70				; BLANK
		.BYTE $F0				; SETS OF 8 LINES FOR BORDER. DLI (DLI1)
;
; SCORE/BONUS DISPLAY
;
		.BYTE $55,<BONSCR,>BONSCR	; BONUS SCREEN MEMORY, ANTIC 5, LMS BONSCR, HSCROL
		.BYTE $10				; 2 BLANK LINES.
;
; BLANK LINES FOR THE TOP SECTION.
;
DLTOPJ		.BYTE $01,<DLTOPU,>DLTOPU		; VERTICAL SCROLL JUMP
DLTOPD		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
DLTOPU		.BYTE $00				; 1 BLANK LINE.
;
; THE INVADERS.
;
DLINV		.BYTE $90				; 2 BLANK LINES, DLI (DLI2)
DLINV1		.BYTE $54,$00,>INVL1M			; INVADERS LINE 1, ANTIC 4, LMS INVL1, HSCROL
		.BYTE $90				; 2 BLANK LINES, DLI (DLI3)
DLINV2		.BYTE $54,$00,>INVL2M			; INVADERS LINE 2, ANTIC 4, LMS INVL2, HSCROL
		.BYTE $90				; 2 BLANK LINES, DLI (DLI4)
DLINV3		.BYTE $54,$00,>INVL3M			; INVADERS LINE 3, ANTIC 4, LMS INVL3, HSCROL
		.BYTE $90				; 2 BLANK LINES, DLI (DLI5)
DLINV4		.BYTE $54,$00,>INVL4M			; INVADERS LINE 4, ANTIC 4, LMS INVL4, HSCROL
		.BYTE $90				; 2 BLANK LINES, DLI (DLI6)
DLINV5		.BYTE $54,$00,>INVL5M			; INVADERS LINE 5, ANTIC 4, LMS INVL4, HSCROL

;
; BLANK LINES FOR THE BOTTOM SECTION.
;

DLBOTJ		.BYTE $01,<DLBOTU,>DLBOTU		; VERTICAL SCROLL JUMP INSTRUCTION

DLBOTU		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $00				; 1 BLANK LINE.
		.BYTE $CE,<SHIELDM,>SHIELDM		; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
		.BYTE $8E				; 1 BLANK LINE.
DLBOTD		.BYTE $80				; 1 BLANK LINE.

;
; PLAYER DISPLAY
;
		.BYTE $80				; 1 BLANK LINE
DLPLYR		.BYTE $54,<PLRML,>PLRML			; PLAYER MOVEMENT LINE, ANTIC 4, LMS PLRM, HSCROL

;
; MOON/SCORE DISPLAY
;

DLMOON		.BYTE $80				; 1 BLANK LINE, DLI (DLI8)
DLMOON1		.BYTE $54,<MOONM1+$DC,>MOONM1		; MOON LINE 1, ANTIC 4, LMS MOONM1, HSCROL
DLMOON2		.BYTE $54,<MOONM2+$DC,>MOONM2		; MOON LINE 2, ANTIC 4, LMS MOONM2, HSCROL
DLMOON3		.BYTE $54,<MOONM3+$DC,>MOONM3		; MOON LINE 3, ANTIC 4, LMS MOONM3, HSCROL
DLMOON4		.BYTE $54,<MOONM4+$DC,>MOONM4		; MOON LINE 4, ANTIC 4, LMS MOONM4, HSCROL
		.BYTE $80				; 1 BLANK LINE, DLI (DLI9)
		.BYTE $54,<SCRM,>SCRM			; SCORE, ANTIC 4, LMS SCRM, HSCROL
		.BYTE $54,<SCRM2,>SCRM2
DLEND		.BYTE $41,<DLIST,>DLIST			; JUMP BACK TO START OF DLIST AFTER VBLANK


;
; SCREEN MEMORY BLOCKS (1 PAGE A PIECE)
;


;
; BONUS ALIEN.
;
		*=$1000
BONSCR		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$15,$10,$10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; INVADERS LINE 1
;
INVL1		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
INVL1M		.BYTE $00,$00,$00,$00,$00,$01,$02,$00,$01,$02,$00,$01,$02,$00,$01,$02
		.BYTE $00,$01,$02,$00,$01,$02,$00,$01,$02,$00,$01,$02,$00,$01,$02,$00
		.BYTE $01,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; INVADERS LINE 2
;
INVL2		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
INVL2M		.BYTE $00,$00,$00,$00,$00,$05,$06,$00,$05,$06,$00,$05,$06,$00,$05,$06
		.BYTE $00,$05,$06,$00,$05,$06,$00,$05,$06,$00,$05,$06,$00,$05,$06,$00
		.BYTE $05,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; INVADERS LINE 3
;
INVL3		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
INVL3M		.BYTE $00,$00,$00,$00,$00,$09,$0A,$00,$09,$0A,$00,$09,$0A,$00,$09,$0A
		.BYTE $00,$09,$0A,$00,$09,$0A,$00,$09,$0A,$00,$09,$0A,$00,$09,$0A,$00
		.BYTE $09,$0A,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; INVADERS LINE 4
;
INVL4		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
INVL4M		.BYTE $00,$00,$00,$00,$00,$07,$08,$00,$07,$08,$00,$07,$08,$00,$07,$08
		.BYTE $00,$07,$08,$00,$07,$08,$00,$07,$08,$00,$07,$08,$00,$07,$08,$00
		.BYTE $07,$08,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; INVADERS LINE 5
;
INVL5		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
INVL5M		.BYTE $00,$00,$00,$00,$00,$0B,$0C,$00,$0B,$0C,$00,$0B,$0C,$00,$0B,$0C
		.BYTE $00,$0B,$0C,$00,$0B,$0C,$00,$0B,$0C,$00,$0B,$0C,$00,$0B,$0C,$00
		.BYTE $0B,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; PLAYER MEMORY
;
PLRM		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
PLRML		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$1A
		.BYTE $1B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; MOON LINE 1
;
MOONM1		.BYTE $42,$43,$44,$42,$44,$43,$45,$46,$47,$43,$45,$46,$47,$42,$43,$45
		.BYTE $43,$45,$43,$47,$48,$45,$46,$49,$44,$42,$46,$47,$43,$45,$42,$44
		.BYTE $42,$44,$46,$45,$43,$42,$45,$47,$46,$42,$43,$44,$45,$46,$47,$48
		.BYTE $49,$45,$44,$43,$46,$48,$47,$44,$43,$45,$46,$42,$47,$48,$45,$44
		.BYTE $43,$46,$47,$43,$42,$44,$46,$45,$46,$47,$48,$49,$45,$43,$42,$47
		.BYTE $42,$46,$45,$43,$44,$45,$46,$47,$48,$43,$45,$44,$42,$46,$47,$42
		.BYTE $43,$42,$47,$46,$45,$42,$48,$46,$45,$44,$47,$49,$43,$44,$46,$48
		.BYTE $46,$44,$43,$48,$49,$42,$43,$44,$45,$46,$43,$48,$49,$43,$42,$46
		.BYTE $45,$42,$44,$46,$43,$47,$48,$42,$47,$42,$45,$43,$42,$47,$45,$43
		.BYTE $43,$44,$46,$47,$43,$45,$46,$47,$48,$42,$45,$46,$43,$46,$47,$42
		.BYTE $46,$43,$42,$48,$47,$46,$45,$46,$48,$43,$42,$47,$43,$44,$45,$46
		.BYTE $42,$47,$45,$49,$46,$42,$43,$44,$45,$46,$47,$48,$49,$42,$44,$47
		.BYTE $46,$43,$42,$48,$45,$44,$42,$47,$49,$45,$42,$45,$47,$45,$42,$48
		.BYTE $43,$45,$47,$46,$44,$42,$45,$48,$43,$42,$48,$49,$42,$48,$47,$42
		.BYTE $46,$44,$42,$47,$45,$45,$46,$47,$48,$49,$43,$45,$47,$45,$46,$48
		.BYTE $45,$43,$42,$48,$46,$43,$49,$46,$45,$43,$42,$47,$48,$49,$43,$44

;
; MOON LINE 2
;
MOONM2		.BYTE $52,$54,$53,$4A,$4B,$55,$52,$57,$52,$52,$56,$55,$56,$55,$54,$54
		.BYTE $57,$56,$54,$55,$54,$54,$55,$56,$56,$55,$53,$54,$54,$53,$55,$53
		.BYTE $55,$57,$56,$54,$52,$52,$57,$52,$57,$57,$51,$52,$52,$52,$52,$52
		.BYTE $54,$54,$52,$52,$56,$56,$53,$51,$53,$53,$57,$56,$56,$56,$56,$55
		.BYTE $52,$52,$54,$53,$55,$55,$52,$55,$56,$52,$53,$54,$54,$57,$55,$56
		.BYTE $56,$53,$55,$55,$52,$52,$57,$54,$53,$52,$52,$53,$52,$53,$52,$52
		.BYTE $57,$54,$56,$57,$53,$51,$52,$53,$57,$51,$55,$55,$53,$52,$56,$53
		.BYTE $53,$55,$57,$53,$55,$55,$53,$52,$52,$56,$56,$52,$57,$51,$54,$54
		.BYTE $52,$56,$55,$57,$53,$56,$54,$58,$52,$53,$52,$55,$55,$57,$57,$55
		.BYTE $57,$57,$54,$55,$52,$57,$55,$57,$53,$52,$56,$57,$52,$55,$55,$56
		.BYTE $53,$54,$53,$53,$55,$53,$57,$56,$54,$51,$54,$54,$53,$53,$53,$57
		.BYTE $52,$52,$52,$52,$56,$52,$52,$52,$55,$56,$52,$52,$56,$57,$52,$52
		.BYTE $57,$56,$54,$56,$57,$55,$57,$56,$56,$53,$53,$55,$55,$53,$56,$53 
		.BYTE $55,$55,$56,$54,$54,$54,$53,$57,$57,$52,$56,$53,$53,$53,$53,$54
		.BYTE $52,$54,$53,$4A,$4B,$55,$52,$57,$52,$52,$56,$55,$56,$55,$54,$54
		.BYTE $57,$56,$54,$55,$54,$54,$55,$56,$56,$55,$53,$54,$54,$53,$55,$53


;
; MOON LINE 3
;
MOONM3		.BYTE $52,$53,$55,$4C,$4D,$57,$54,$52,$54,$52,$53,$54,$55,$54,$55,$55
		.BYTE $54,$54,$55,$54,$55,$54,$53,$53,$55,$55,$4E,$4F,$56,$55,$54,$54
		.BYTE $56,$52,$56,$52,$56,$52,$55,$56,$52,$52,$55,$52,$54,$52,$53,$52
		.BYTE $57,$56,$54,$55,$52,$55,$56,$54,$53,$53,$56,$53,$52,$53,$51,$54
		.BYTE $52,$54,$52,$56,$53,$53,$57,$52,$55,$56,$57,$56,$53,$56,$55,$56
		.BYTE $53,$53,$54,$54,$54,$57,$55,$55,$53,$57,$52,$57,$55,$55,$54,$54
		.BYTE $54,$52,$53,$53,$55,$56,$52,$56,$56,$55,$53,$54,$56,$57,$52,$55
		.BYTE $55,$55,$55,$57,$56,$55,$51,$54,$57,$54,$54,$52,$53,$55,$53,$52
		.BYTE $56,$54,$53,$52,$52,$54,$53,$53,$53,$53,$55,$53,$52,$53,$54,$54
		.BYTE $57,$52,$55,$53,$53,$53,$56,$52,$52,$52,$56,$54,$54,$52,$56,$57
		.BYTE $53,$53,$52,$55,$54,$52,$54,$55,$54,$55,$53,$56,$56,$53,$54,$55
		.BYTE $54,$54,$51,$56,$55,$54,$52,$54,$55,$56,$52,$57,$55,$55,$53,$54
		.BYTE $52,$55,$54,$54,$56,$55,$51,$53,$52,$54,$54,$55,$53,$56,$52,$52
		.BYTE $56,$56,$55,$53,$57,$56,$56,$52,$53,$53,$56,$54,$52,$54,$52,$53
		.BYTE $52,$53,$55,$4C,$4D,$57,$54,$52,$54,$52,$53,$54,$55,$54,$55,$55
		.BYTE $54,$54,$55,$54,$55,$54,$53,$53,$55,$55,$4E,$4F,$56,$55,$54,$54


;
; MOON LINE 4
;
MOONM4		.BYTE $53,$55,$56,$52,$55,$55,$53,$55,$53,$55,$56,$53,$53,$55,$56,$55
		.BYTE $54,$54,$57,$53,$56,$54,$54,$54,$54,$54,$50,$51,$54,$53,$54,$53
		.BYTE $55,$53,$54,$56,$54,$53,$55,$53,$56,$53,$52,$53,$52,$54,$53,$52
		.BYTE $52,$56,$53,$54,$57,$52,$56,$56,$52,$52,$51,$52,$54,$56,$52,$56
		.BYTE $53,$54,$52,$53,$55,$56,$54,$57,$53,$56,$53,$56,$56,$55,$56,$54
		.BYTE $56,$53,$53,$52,$54,$55,$52,$55,$57,$54,$52,$53,$53,$54,$54,$52
		.BYTE $57,$52,$56,$53,$52,$54,$56,$53,$55,$57,$55,$53,$54,$52,$53,$53
		.BYTE $55,$55,$55,$55,$53,$53,$55,$54,$56,$54,$56,$56,$57,$53,$54,$57
		.BYTE $54,$56,$53,$53,$54,$52,$53,$52,$54,$53,$52,$53,$54,$57,$56,$55
		.BYTE $52,$54,$54,$52,$57,$55,$54,$54,$53,$52,$57,$56,$53,$55,$54,$54
		.BYTE $53,$53,$52,$54,$55,$56,$57,$56,$52,$56,$54,$52,$52,$52,$54,$53
		.BYTE $54,$52,$51,$56,$56,$55,$56,$54,$56,$51,$52,$56,$57,$54,$52,$52
		.BYTE $56,$53,$53,$52,$53,$54,$52,$53,$55,$55,$57,$52,$55,$56,$53,$57
		.BYTE $55,$56,$56,$53,$52,$53,$53,$56,$54,$57,$55,$54,$56,$57,$55,$54
		.BYTE $53,$55,$56,$52,$55,$55,$53,$55,$53,$55,$56,$53,$53,$55,$56,$55
		.BYTE $54,$54,$57,$53,$56,$54,$54,$54,$54,$54,$50,$51,$54,$53,$54,$53

;
; SCORE DISPLAY
;
SCRM		.SBYTE "    0000000000            0000000000"
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; SCORE DISPLAY
;
SCRM2		.SBYTE "    1UP :; x 3            2UP :; x 3"
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00

;
; SCREEN MEMORY FOR THE SHIELDS (MODE E)
;
SHIELDM		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 ; LINE 01L
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 ; LINE 01H
		.BYTE $00,$3F,$F0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$3F ; LINE 02L
		.BYTE $F0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$FC,$00 ; LINE 02H
		.BYTE $00,$FF,$FC,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$FF ; LINE 03L
		.BYTE $FC,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$3F,$FF,$00 ; LINE 03H
		.BYTE $03,$FF,$FF,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$03,$FF ; LINE 04L
		.BYTE $FF,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$FF,$FF,$C0 ; LINE 04H
		.BYTE $0F,$FF,$FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$FF ; LINE 05L
		.BYTE $FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$03,$FF,$FF,$F0 ; LINE 05H
		.BYTE $0F,$FF,$FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$FF ; LINE 06L
		.BYTE $FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$03,$FF,$FF,$F0 ; LINE 06H
		.BYTE $0F,$FF,$FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$FF ; LINE 07L
		.BYTE $FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$03,$FF,$FF,$F0 ; LINE 07H
		.BYTE $0F,$FF,$FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$FF ; LINE 08L
		.BYTE $FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$03,$FF,$FF,$F0 ; LINE 08H
		.BYTE $0F,$FF,$FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$FF ; LINE 09L
		.BYTE $FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$03,$FF,$FF,$F0 ; LINE 09H
		.BYTE $0F,$FF,$FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$FF ; LINE 10L
		.BYTE $FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$03,$FF,$FF,$F0 ; LINE 10H
		.BYTE $0F,$FF,$FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$FF ; LINE 11L
		.BYTE $FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$03,$FF,$FF,$F0 ; LINE 11H
		.BYTE $0F,$FF,$FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$FF ; LINE 12L
		.BYTE $FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$03,$FF,$FF,$F0 ; LINE 12H
		.BYTE $0F,$FF,$FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$FF ; LINE 13L
		.BYTE $FF,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$03,$FF,$FF,$F0 ; LINE 13H
		.BYTE $0F,$F0,$3F,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$F0 ; LINE 14L
		.BYTE $3F,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$03,$FC,$0F,$F0 ; LINE 14H
		.BYTE $0F,$C0,$0F,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$C0 ; LINE 15L
		.BYTE $0F,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$03,$F0,$03,$F0 ; LINE 15H
		.BYTE $0F,$00,$03,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$00 ; LINE 16L
		.BYTE $03,$C0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$03,$C0,$00,$F0 ; LINE 16H

;
; PMBASE TABLES FOR GAME.
;	
		*=$2800
PMB		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
PMBMS		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
		.BYTE $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
PMBP0		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
PMBP1		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
PMBP2		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
PMBP3		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
		.BYTE $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
;
; RUN ADDRESS
;
		*=$02E0
		.BYTE <TOP,>TOP
